@@ -1,8 +1,8 @@
 package DBIx::XHTML_Table;
 
 use strict;
-use vars qw($VERSION);
-$VERSION = '1.38';
+use warnings;
+our $VERSION = '1.40';
 
 use DBI;
 use Carp;
@@ -127,7 +127,7 @@ sub modify {
 
 		# there is only one caption - no need to rotate attribs
 		if (ref $cols->{'style'} eq 'HASH') {
-			$cols->{'style'} = join('; ',map { "$_: ".$cols->{'style'}->{$_} } keys %{$cols->{'style'}}) . ';';
+			$cols->{'style'} = join('; ',map { "$_: ".$cols->{'style'}->{$_} } sort keys %{$cols->{'style'}}) . ';';
 		}
 
 		$self->{'global'}->{$tag."_attribs"} = $cols;
@@ -620,7 +620,8 @@ sub _tag_it {
 	my $text = "<\L$name\E";
 
 	# build the attributes if any - skip blank vals
-	while(my ($k,$v) = each %{$attribs}) {
+    for my $k (sort keys %{$attribs}) {
+        my $v = $attribs->{$k};
 		if (ref $v eq 'HASH') {
 			$v = join('; ', map { 
 				my $attrib = $_;
@@ -628,7 +629,7 @@ sub _tag_it {
 					? _rotate($v->{$_}) 
 					: $v->{$_};
 				join(': ',$attrib,$value||'');
-			} keys %$v) . ';';
+			} sort keys %$v) . ';';
 		}
 		$v = _rotate($v) if (ref $v eq 'ARRAY');
 		$text .= qq| \L$k\E="$v"| unless $v =~ /^$/;
@@ -728,7 +729,7 @@ __END__
 
 =head1 NAME
 
-DBIx::XHTML_Table - SQL query result set to HTML table.
+DBIx::XHTML_Table - SQL query result set to XHTML table.
 
 =head1 SYNOPSIS
 
@@ -767,14 +768,29 @@ where the concern for presentation and logic seperation is overkill.
 Providing logic or editable data is beyond the scope of this module,
 but it is capable of doing such.
 
-=head1 HOME PAGE
+DBIx::XHTML_Table is over one decade old now and has been in
+need of a rewrite for a long time. Two new modules are being
+developed to handle the most of the current responsibilites. This
+module will not be retired, but usage of the following is encouraged
+once they have both matured to version 1.0 and greater:
 
-The DBIx::XHTML_Table homepage is now available, but still under
-construction. A partially complete FAQ and Cookbook are available
-there, as well as the Tutorial, Download and Support info: 
+=over 4
+
+=item * L<DBIx::HTML>
+
+=item * L<Spreadsheet::HTML>
+
+=back
+
+=head1 WEBSITE
+
+More documentation (tutorial, cookbook, FAQ, etc.) can be found at
 
   http://www.unlocalhost.com/XHTML_Table/
-  http://jeffa.perlmonk.org/XHTML_Table/
+
+=head1 GITHUB
+
+  https://github.com/jeffa/DBIx-XHTML_Table
 
 =head1 CONSTRUCTOR
 
